Signature

Struct Signature 

pub struct Signature { /* private fields */ }
Ed448 signature.

This type represents a container for the byte serialization of an Ed448 signature, and does not necessarily represent well-formed field or curve elements.

Signature verification libraries are expected to reject invalid field elements at the time a signature is verified.

Implementations

Source

impl Signature

pub const BYTE_SIZE: usize

Size of an encoded Ed448 signature in bytes (114-bytes).

pub fn from_bytes(bytes: &SignatureBytes) -> Self

Parse an Ed448 signature from a byte slice.

pub fn from_slice(bytes: &[u8]) -> Result<Self>

Parse an Ed448 signature from a byte slice.

Errors
  • Returns Error if the input byte slice is not 114-bytes.
pub fn r_bytes(&self) -> &ComponentBytes

Bytes for the R component of a signature.

pub fn s_bytes(&self) -> &ComponentBytes

Bytes for the s component of a signature.

pub fn to_bytes(&self) -> SignatureBytes

Return the inner byte array.

pub fn from_components( r: impl Into<ComponentBytes>, s: impl Into<ComponentBytes>, ) -> Self

Create a Signature from the serialized r and s component values which comprise the signature.