pub struct Signature { /* private fields */ }Expand description
Ed448 signature.
This type represents a container for the byte serialization of an Ed448 signature, and does not necessarily represent well-formed field or curve elements.
Signature verification libraries are expected to reject invalid field elements at the time a signature is verified.
Implementations
Sourceimpl Signature
impl Signature
Sourcepub fn from_bytes(bytes: &SignatureBytes) -> Self
pub fn from_bytes(bytes: &SignatureBytes) -> Self
Parse an Ed448 signature from a byte slice.
Sourcepub fn from_slice(bytes: &[u8]) -> Result<Self>
pub fn from_slice(bytes: &[u8]) -> Result<Self>
Sourcepub fn r_bytes(&self) -> &ComponentBytes
pub fn r_bytes(&self) -> &ComponentBytes
Bytes for the R component of a signature.
Sourcepub fn s_bytes(&self) -> &ComponentBytes
pub fn s_bytes(&self) -> &ComponentBytes
Bytes for the s component of a signature.
Sourcepub fn to_bytes(&self) -> SignatureBytes
pub fn to_bytes(&self) -> SignatureBytes
Return the inner byte array.
Sourcepub fn from_components(
r: impl Into<ComponentBytes>,
s: impl Into<ComponentBytes>,
) -> Self
pub fn from_components( r: impl Into<ComponentBytes>, s: impl Into<ComponentBytes>, ) -> Self
Create a Signature from the serialized r and s component values
which comprise the signature.